@@ -12,12 +12,10 @@
 from whylabs_client.model.aws_marketplace_metadata import AWSMarketplaceMetadata
 from whylabs_client.model.action_type import ActionType
 from whylabs_client.model.add_membership_request import AddMembershipRequest
-from whylabs_client.model.alerts_path import AlertsPath
 from whylabs_client.model.async_log_response import AsyncLogResponse
-from whylabs_client.model.close_session_response import CloseSessionResponse
 from whylabs_client.model.column_schema import ColumnSchema
+from whylabs_client.model.create_session_request import CreateSessionRequest
 from whylabs_client.model.create_session_response import CreateSessionResponse
-from whylabs_client.model.create_session_upload_response import CreateSessionUploadResponse
 from whylabs_client.model.create_user_request import CreateUserRequest
 from whylabs_client.model.dto_auto_scale_dto import DTOAutoScaleDTO
 from whylabs_client.model.dto_aws_attributes_dto import DTOAwsAttributesDTO
@@ -45,24 +43,20 @@ from whylabs_client.model.email_notification_action import EmailNotificationActi
 from whylabs_client.model.entity_schema import EntitySchema
 from whylabs_client.model.entity_weight_record import EntityWeightRecord
 from whylabs_client.model.entity_weight_record_metadata import EntityWeightRecordMetadata
-from whylabs_client.model.events_path import EventsPath
 from whylabs_client.model.feature_flags import FeatureFlags
-from whylabs_client.model.get_alerts_paths_response import GetAlertsPathsResponse
 from whylabs_client.model.get_connection_request import GetConnectionRequest
 from whylabs_client.model.get_connection_response import GetConnectionResponse
+from whylabs_client.model.get_dataset_metadata_response import GetDatasetMetadataResponse
 from whylabs_client.model.get_default_membership_response import GetDefaultMembershipResponse
-from whylabs_client.model.get_events_path_response import GetEventsPathResponse
 from whylabs_client.model.get_marketplace_metadata_response import GetMarketplaceMetadataResponse
 from whylabs_client.model.get_memberships_response import GetMembershipsResponse
 from whylabs_client.model.get_monitor_config_v2_response import GetMonitorConfigV2Response
 from whylabs_client.model.get_notification_settings_response import GetNotificationSettingsResponse
 from whylabs_client.model.get_session_response import GetSessionResponse
-from whylabs_client.model.inline_object import InlineObject
 from whylabs_client.model.list_jobs_request import ListJobsRequest
 from whylabs_client.model.list_jobs_response import ListJobsResponse
 from whylabs_client.model.list_models_response import ListModelsResponse
 from whylabs_client.model.list_organization_memberships_response import ListOrganizationMembershipsResponse
-from whylabs_client.model.list_segments_response import ListSegmentsResponse
 from whylabs_client.model.list_user_api_keys import ListUserApiKeys
 from whylabs_client.model.log_async_request import LogAsyncRequest
 from whylabs_client.model.log_reference_request import LogReferenceRequest
@@ -74,7 +68,7 @@ from whylabs_client.model.membership_metadata import MembershipMetadata
 from whylabs_client.model.missing_recent_data_request_config import MissingRecentDataRequestConfig
 from whylabs_client.model.missing_recent_profiles_request_config import MissingRecentProfilesRequestConfig
 from whylabs_client.model.missing_values_monitor_request_config import MissingValuesMonitorRequestConfig
-from whylabs_client.model.model_metadata import ModelMetadata
+from whylabs_client.model.model_metadata_response import ModelMetadataResponse
 from whylabs_client.model.model_type import ModelType
 from whylabs_client.model.monitor_config import MonitorConfig
 from whylabs_client.model.monitor_config_version import MonitorConfigVersion
@@ -103,14 +97,13 @@ from whylabs_client.model.register_databricks_connection_response import Registe
 from whylabs_client.model.remove_membership_request import RemoveMembershipRequest
 from whylabs_client.model.request_feature_monitor_config import RequestFeatureMonitorConfig
 from whylabs_client.model.request_monitor_config import RequestMonitorConfig
+from whylabs_client.model.response import Response
 from whylabs_client.model.role import Role
 from whylabs_client.model.run_job_request import RunJobRequest
 from whylabs_client.model.run_job_response import RunJobResponse
 from whylabs_client.model.schema_metadata import SchemaMetadata
 from whylabs_client.model.seasonal_arima_request_config import SeasonalARIMARequestConfig
 from whylabs_client.model.segment import Segment
-from whylabs_client.model.segment_metadata import SegmentMetadata
-from whylabs_client.model.segment_summary import SegmentSummary
 from whylabs_client.model.segment_tag import SegmentTag
 from whylabs_client.model.segment_weight import SegmentWeight
 from whylabs_client.model.session_metadata import SessionMetadata
